#
# spec file for package pm-utils
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pm_libdir %{_prefix}/lib/%{name}/
%define pm_quirkdbdir %{pm_libdir}/video-quirks
%define pm_sysconfdir %{_sysconfdir}/pm/config.d/
%define gitversion 2

Name:           pm-utils
Version:        1.4.1
Release:        5.24.1
Summary:        Tools to suspend and hibernate computers
License:        GPL-2.0+
Group:          System/Base
Url:            http://pm-utils.freedesktop.org/wiki/
Source0:        %{name}-%{version}-suse-%{gitversion}.tar.bz2
# http://gitorious.org/opensuse/pm-utils-suse
Source1:        http://pm-utils.freedesktop.org/releases/pm-quirks-20100316.tar.bz2
Source2:        rc.cpufreq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

PreReq:         %insserv_prereq

# hooks requires some external tools
Requires:       coreutils
Requires:       ethtool
Requires:       gawk
Requires:       grep
Requires:       module-init-tools
Requires:       sed

Requires:       upower

%description
pm-utils provide simple shell command line tools to suspend and
hibernate computers that can be used to run vendor or distro supplied
scripts on suspend and resume.

Authors:
--------
    Bill Nottingham <notting@redhat.com>
    Peter Jones <pjones@redhat.com>
    David Zeuthen <davidz@redhat.com>
    Richard Hughes <richard@hughsie.com>

%package ndiswrapper
Summary:        The pm-utils hook for ndiswrapper
Group:          System/Base
Supplements:    ndiswrapper
Requires:       %{name} = %{version}

%description ndiswrapper
pm-utils provide simple shell command line tools to suspend and
hibernate computers that can be used to run vendor or distro supplied
scripts on suspend and resume. This package installs the 75ndiswrapper hook.


%prep
%setup -n %{name} -a 1 

%build
%{configure} \
  --docdir=%{_defaultdocdir}/%{name} \
  --libdir=%{_prefix}/lib
%{__make} -d

%install
%{makeinstall}
# bnc#663067
%{__rm} %{buildroot}/%{pm_libdir}/power.d/harddrive
#FIXME: should be installed by make install
%{__install} -m 644 man/*.1 %{buildroot}/%{_mandir}/man1
%{__install} -m 644 man/*.8 %{buildroot}/%{_mandir}/man8
#quirks
%{__install} -d -m 0755 %{buildroot}%{pm_quirkdbdir}
%{__install} -m 0644 *.quirkdb %{buildroot}%{pm_quirkdbdir}
#SUSE hooks
%{__install} -m 0755 pm/sleep.d/02rtcwake %{buildroot}/%{pm_libdir}/sleep.d/
%{__install} -m 0755 pm/sleep.d/06autofs %{buildroot}/%{pm_libdir}/sleep.d/
%{__install} -m 0755 pm/sleep.d/30s2disk-check %{buildroot}/%{pm_libdir}/sleep.d/
%{__install} -m 0755 pm/sleep.d/45pcmcia %{buildroot}/%{pm_libdir}/sleep.d/
%{__install} -m 0755 pm/sleep.d/50rcnetwork %{buildroot}/%{pm_libdir}/sleep.d/
%{__install} -m 0755 pm/sleep.d/75ndiswrapper %{buildroot}/%{pm_libdir}/sleep.d/
%{__install} -m 0755 pm/sleep.d/80acpi-fan %{buildroot}/%{pm_libdir}/sleep.d/
%{__install} -m 0755 pm/sleep.d/80videobios %{buildroot}/%{pm_libdir}/sleep.d/
%{__install} -m 0755 pm/sleep.d/99info %{buildroot}/%{pm_libdir}/sleep.d/
%{__install} -m 0644 pm/config.d/* %{buildroot}/%{pm_sysconfdir}/
# powersave command is back
%{__install} -m 0755 bin/powersave %{buildroot}/%{_bindir}
%{__install} -d -m 0755 %{buildroot}/%{_localstatedir}/log
touch %{buildroot}/%{_localstatedir}/log/pm-suspend.log
# changing libdir in configure has the side-effect of misinstalling the
# pkg-config file (/usr/lib/pkgconfig is not searched on x86_64). Since we have
# no arch-specific data, we put it in datadir.
%{__install} -d -m 0755 %{buildroot}%{_datadir}/pkgconfig
mv %{buildroot}%{_prefix}/lib/pkgconfig/%{name}.pc %{buildroot}%{_datadir}/pkgconfig
# install cpufreq init script
install -D -m 0755 %{S:2} %{buildroot}%{_sysconfdir}/init.d/cpufreq
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf %{_sysconfdir}/init.d/cpufreq %{buildroot}%{_sbindir}/rccpufreq

%clean
rm -rf %{buildroot}

%preun
%stop_on_removal cpufreq

%post
%fillup_and_insserv -f -y cpufreq

%triggerun -- %{name} < 1.4.1-3
# Forcefully enable the service on upgrades from versions where the service
# didn't exist or wasn't necessarily enabled by default. Without this, on
# upgrades, the service will not be enabled.
%insserv_force_if_yast cpufreq

%postun
%restart_on_update cpufreq
%insserv_cleanup

%files
%defattr (-,root,root)
%doc README AUTHORS README.smart-suspend-to-RAM
%attr(0755,root,root) %{_bindir}/*
%{_sbindir}/*
%config %{_sysconfdir}/init.d/cpufreq
%{_sysconfdir}/pm/
%config(noreplace) %{_sysconfdir}/pm/config.d/rtcwake.config
%{pm_libdir}
%exclude %{pm_libdir}/sleep.d/75ndiswrapper
%{_mandir}/man1/*
%{_mandir}/man8/*
%ghost %verify(not md5 size mtime) /var/log/pm-suspend.log
%{_datadir}/pkgconfig/%{name}.pc

%files ndiswrapper
%defattr (-,root,root)
%{pm_libdir}/sleep.d/75ndiswrapper

%changelog
* Tue Apr  3 2012 vdziewiecki@suse.com
-Used git repository git@gitorious.org:opensuse/pm-utils.git, a branch of git://anongit.freedesktop.org/git/pm-utils. It now contains all the suse additions and all the patches to avoid having suse hooks in a separate package
* Mon Mar 19 2012 vdziewiecki@suse.com
  Fixed  bnc#751887 - Hibernation failure after security patches applied;
  Fixed  bnc#751621 - /usr/lib/pm-utils/sleep.d/06autofs unconditionally (re)starts autofs
  Fixed  bnc#751811 - pm-suspend generates defective /var/log/pm-suspend.log file
* Wed Feb 29 2012 mvyskocil@suse.cz
- fix bnc#749031: Add pm-utils-dhcp-interfaces.patch, fix script
  50rcnetwork error and update savestate/restorestate functions.
- add pm-utils-1.4.1-vtXX-upower-battery-AC-adapter.patch (bnc#670074)
* Mon Feb 13 2012 binli@opensuse.org
- Add pm-utils-1.4.1-networkmanager.patch, the methods
  org.freedesktop.NetworkManager.{sleep,wake} have been replaced in
  post-6.x NetworkManager by org.freedesktop.NetworkManager.Sleep
  which takes a boolean argument(bnc#735837).
* Tue Mar  1 2011 mvyskocil@suse.cz
- Fix bnc#663067 - remove harddrive power.d hook
* Sun Feb 13 2011 vuntz@opensuse.org
- Use a %%triggerun on pm-utils < 1.4.1-3 (should be this version)
  to forcefully enable the cpufreq service, since else, it's not
  enabled on upgrades. Thanks to Kay Sievers for the hint!
  Fix bnc#653540.
* Wed Jan 26 2011 vuntz@opensuse.org
- Update rc.cpufreq:
  + Use acpi_cpufreq instead of acpi-cpufreq for consistency.
  + Do not report failure on start when hardware doesn't support
    frequency scaling. Report "skipped" instead. Based on patch
    from Per Jessen <per@opensuse.org>. Fix bnc#660417.
* Mon Jan  3 2011 trenn@novell.com
- rccpufreq fixups:
  speedstep_centrino functionality is replaced by acpi-cpufreq for quite some
  time and is not compiled on our latest kernels anymore
  (CONFIG_X86_SPEEDSTEP_CENTRINO)
  Try to load mostly used cpufreq driver (acpi-cpufreq) first for speedup
  reasons
* Tue Oct 12 2010 vuntz@opensuse.org
- Add a cpufreq init script, with code that was originally in hal
  init script. Since hal is getting killed, we need to move this
  elsewhere. This will help with bnc#612131.
  + Install rc.cpufreq as /etc/init.d/cpufreq and link it from
    /usr/sbin/rccpufreq.
  + Add %%insserv_prereq PreReq.
  + Add scriptlets to handle this init script. We enable it by
    default.
* Mon Sep 20 2010 mvyskocil@suse.cz
- Update to 1.4.1
  * New power.d hooks:
  - disable_wol (obsoletes wol, $WOL)
  - hal-cd-polling
  - harddrive,
  - intel-audio-powersave (obsoletes sound-pm, $SOUND_PM),
  - journal-commit,
  - laptop-mode
  - pcie_aspm,
  - readahead,
  - sata_alpm (obsoletes sata_pm, $SATA_PM)
  - wireless (obsoletes iwl-pm, $IWL_PM)
  - xfs_buffer
  * Load hook blacklist for power.d hooks
  * Fix paths for sched_powersave script
  * Try falling back to standby suspend of mem is not available.
  * Use flock for more robust lock file handling
  * Make tuxonice methods chvt if using a userspace UI.
  * Autodetect sleep modules by default instead of forcing the kernel one.
  * Rewrote the sched-powersave hook to eliminate redundancy.
  * Help functionality to pm-powersave
- SUSE aditions
  * set and check the governors via sysfs - bnc#619750
  * do a sanity check on S2DISK_CONF
  * fix bnc#617667: 50rcnetwork sleep hook cannot work
  * remove power.d hooks already in upstream pm-utils 1.4.0+
  - iwl-pm and $IWL_PM config variable replaced by wireless hook, no config variable
  - sata-pm and $SATA_PM replaced by sata_alpm, $SATA_ALPM_ENABLE
  - sound-pm and $SOUND_PM replaced by intel-audio-powersave, $INTEL_AUDIO_POWERSAVE
  - wol and $WOL replaced by disable_wol, no config variable
* Mon Jul  5 2010 seife@opensuse.org
- bash scripts are best if their logic is correct (bnc#619734)
* Tue Jun 29 2010 coolo@novell.com
- bash scripts are better if they follow the syntax
* Sat Jun 26 2010 seife@opensuse.org
- fixes bnc#617667: 50rcnetwork sleep hook cannot work
* Wed Jun 23 2010 mvyskocil@suse.cz
- fixes bnc# 615646 - Suspending with upower/dk-power blocks the calling process
  * pm-utils-1.3.0-direct-on_ac_power.patch
* Mon Jun 14 2010 mvyskocil@suse.cz
- fixes bnc#603291: restart DHCP clients if traditional ifup is used
- fixes bnc#613967: typo in stderr redirection
* Thu May  6 2010 mvyskocil@suse.cz
- refresh patches to fix a build
* Fri Apr 30 2010 mvyskocil@suse.cz
- fix bnc#304995: export SUSE_IGNORE_FBMODES to ignore fb.modes read from DirectFB
* Wed Apr  7 2010 mvyskocil@suse.cz
- fix power.d/iwl-pm hook
* Fri Apr  2 2010 mvyskocil@suse.cz
- Updated to 1.3.0: fix bnc#590709
  * pm-utils does not depends on HAL anymore
  * import HAL's fdi quirks
  * track whether suspend/hibernate succeeded, and handle things as appropriately as we can.
  * Native suspend-hybrid method.
  * Profile the entire suspend/resume process using PM_PROFILE.
- backport the existing patches, split and sort them
- remove the HAL dependencies from power.d hooks wol and sata-pm
- use explicit dependencies on external tools
- powersave is back - now partially supports upower
* Tue Feb 16 2010 seife@opensuse.org
- fix the location of S2DISK_CONF
* Sat Feb 13 2010 vuntz@opensuse.org
- Move the pkg-config file to /usr/share/pkgconfig to have it
  findable on x86_64. We could also move it to
  /usr/%%_lib/pkgconfig, but we explicitly change libdir to not be
  arch-specific, so /usr/share is more appropriate.
* Tue Dec 15 2009 mvyskocil@suse.cz
- suspend-to-file support (bnc#309522)
* Wed Nov 25 2009 mvyskocil@suse.cz
- Updated to 1.2.6.1 - fixed bnc#378883
- install all upstream hooks (fixes at least bnc#552346)
- moved ndiswrapper hook to separate package
- backported the smart suspend support
- Obsoleted patches:
  * pm-utils-0.99.3-README-fix.diff
  * pm-utils-0.99.4-QUIRK-variables-changed.diff
  * pm-utils-0.99.4-fix-broken-dbus-send.diff
  * pm-utils-0.99.4-on_ac_power-no-dbus-fallback.diff
  * pm-utils-0.99.4-suse.diff
- removed powersave command
* Sun Jun 21 2009 hmacht@suse.de
- add power.d hook script 'wol' and corresponding configuration
  option to /usr/lib/pm-utils/defaults to enable wake on LAN when
  running on AC and disabling it when on DC
* Thu Apr  9 2009 seife@suse.de
- be a bit more thorough in kicking the ACPI fans after resume
- add a paragraph about who is doing the low level suspend stuff
  to the README
* Thu Mar 19 2009 seife@suse.de
- fix a potential problem with S2RAM_QUIRKS_SOURCE=hal (bnc#480803)
* Tue Feb 17 2009 seife@suse.de
- use s2ram options from config and / or "smart suspend" also for
  s2both aka "hybrid suspend" (bnc#476484)
- run the 30s2disk-check hook also during "hybrid suspend"
* Wed Jan 21 2009 hmacht@suse.de
- powersave:
  - Handle "no CPUFreq on this system" gracefully (bnc#462384)
  - Handle "no AC adapter on this system" gracefully (bnc#462383)
  - Print warning that this tool is obsolete and might vanish
- Make SATA power management work with crypte devices (bnc#465797)
* Fri Dec 12 2008 hmacht@suse.de
- install powersave tool which has been in pm-profiler before
  (bnc#457815)
* Thu Nov 27 2008 seife@suse.de
- remove 55battery hook - not needed since HAL 0.5.8
- add sub-second timestamps to the log file for hook profiling
* Wed Nov 12 2008 seife@suse.de
- log the start of suspend operations also to syslog, with a
  reference to the pm-suspend.log file
- added a reference to the documentation to the suspend log
- split off the QUIRK variable changes from
  pm-utils-0.99.4-uswsusp-support.diff into its own diff
* Fri Nov  7 2008 seife@suse.de
- improve suspend logging (log kernel version and commandline)
* Tue Oct 28 2008 anaumov@suse.de
- Added file 01ndiswrapper to documentation directory. It contains
  a possible workaound for resume problems with ndiswrapper
  (bnc#409110)
* Fri Oct 24 2008 hmacht@suse.de
- Minor fix to previous change
- Add basic logging functionality for pm-powersave
* Tue Oct 21 2008 hmacht@suse.de
- Kernel sysfs interfaces changed for the rf_kill switch and the
  wireless power saving methods (bnc#435393)
* Wed Oct  8 2008 seife@suse.de
- export some more variables for compatibility with that other
  pm-utils project: PM_UTILS_LIBDIR PM_UTILS_ETCDIR PM_FUNCTIONS
* Mon Oct  6 2008 seife@suse.de
- add support for "smart" detection of s2ram quirks
- add support for passing in quirks via command line from HAL
- add README.smart-suspend-to-RAM documentation
* Fri Sep 26 2008 seife@suse.de
- fix pm-action and functions for suspend-hybrid
* Wed Sep 24 2008 seife@suse.de
- update the tarball to the latest 0.99.4 upstream CVS which
  includes:
  - manpage fixes
  - fix for config file reading (patch dropped)
  - removal of dangerous laptop-tools hook
  - fixes for hooks running twice in some circumstances
- add support for hybrid suspend (write image to disk, then s2ram,
  FATE#6368)
- workaround broken dbus-send (bnc#427829)
* Fri Sep 12 2008 seife@suse.de
- Add a config file and hook for calling out to rtcwake, letting
  the user wake the computer up after N seconds of sleep or
  hibernation. The hook also respects the NUM_SECONDS_TO_SLEEP
  environment variable that HAL, for example, might set.
  [Fate#302448]
* Thu Jun  5 2008 seife@suse.de
- fix various small bugs in the power.d hooks for sound and iwl
  (bnc #394318)
* Mon May 26 2008 seife@suse.de
- fix an error message from sata-pm if no sata disks are present
* Fri May  9 2008 seife@suse.de
- remove power.d/laptop-tools hook, is now handled much better by
  laptop-mode-tools package
* Sat May  3 2008 hmacht@suse.de
- add hook for enabling audio power management and default to a
  timeout of 10 seconds
- add hook for enabling sata link power management (ALPM), but
  only for the root partition because of hotplug issues
* Mon Apr 28 2008 hmacht@suse.de
- add script 'iwl-pm.sh' to power.d/ for enabling iwl* power
  management
* Wed Nov 28 2007 lrupp@suse.de
- touch %%ghost file in %%install and add %%verify(not md5 size mtime)
- bzip the source
* Tue Nov 27 2007 seife@suse.de
- add the logfile to the filelist (novell bug 280475)
* Mon Sep 24 2007 seife@suse.de
- add README.update in /etc/pm and fix the README in the documen-
  tation to no longer mention /etc/pm/config but the correct paths
  (novell bug 327828).
* Thu Aug 16 2007 hmacht@suse.de
- remove '-s' option from openvt (00clear hook) to avoid flickering
  before suspend to disk
* Wed Jul 25 2007 hmacht@suse.de
- do not switch to console and back in pm-utils. Suspend tools are
  doing this in any case and splashy looks nicer this way
* Tue Jul 24 2007 seife@suse.de
- update to current CVS:
  - our export-variables patch included
  - minor build system tweaks
- fix reading of multiple configuration files
- removed docker hook, is now in dockutils
* Wed Apr  4 2007 seife@suse.de
- use long options for s2disk/s2both, short options will be depre-
  cated
- fix suspend to disk for HIBERNATE_METHOD=userspace
* Mon Mar 26 2007 seife@suse.de
- update to current CVS (version 0.99.3)
  - fix source_configs so it doesn't throw an error when the config
    dir is empty.
- rework userspace-suspend support
- fix exporting of variables
* Tue Mar 20 2007 seife@suse.de
- update to current CVS
  - module unloading and config handling fix integrated upstream
- pm-utils-suse: be more careful selecting the kernel for resume
  (bug 256105)
* Fri Mar 16 2007 seife@suse.de
- fix module unloading, pm-utils-0.99.2-fix-modunload.diff
* Fri Mar 16 2007 seife@suse.de
- update to current CVS
  - pm-utils-0.99.2-fix-stopservice.diff integrated upstream
- fix the handling of config files in /etc/pm/config.d/ (they were
  simply ignored before)
* Wed Mar 14 2007 seife@suse.de
- update to version 0.99.2+ (CVS as of today)
  - move the executables from /etc/pm to /usr/lib/pm-utils
  - config file from /etc/pm/config to /usr/lib/pm-utils/defaults
  - many of our local fixes applied upstream
  - add pm-suspend-hybrid (currently a no-op, will do s2both)
  - add pm-is-supported that will show HAL what suspend modes are
    available
  - use bash for scripts, not sh
  - fix module load/unload problems with module names that have
    "-" and "_".
* Wed Feb 28 2007 seife@suse.de
- fix cpufreq problem on multicore CPUs after resume (bug 227854)
* Tue Feb 20 2007 seife@suse.de
- update to current CVS
  - add pm-reset-swap to reset the swap signature after failed
    suspend to disk
  - some of our fixed incorporated upstream, patches dropped
- no longer unload the button module, kernel is fixed
* Sun Feb 18 2007 seife@suse.de
- support suspend to swap on LVM/EVMS (or generally if the resume
  parameter points to a symlink).
* Wed Dec 20 2006 seife@suse.de
- fix resume problems if the "Failsafe" kernel is listed before
  the "good" kernel in /boot/grub/menu.lst (bug 223722)
- package the disabled hooks in the documentation directory
- disable the 49blutetooth hook
* Tue Dec  5 2006 seife@suse.de
- fix 30s2disk-check hook, so that suspend with the kernel method
  works again (fixes bug 226115)
* Thu Nov 30 2006 seife@suse.de
- fix on_ac_power on desktops with battery powered mice
  (bug 221999)
- make running the hooks slightly more verbose
* Wed Nov 22 2006 seife@suse.de
- fix dualcore cpufreq problem after suspend (bug 223164)
- mark the configfile as "noreplace"
- print "resuming..." during resume
* Mon Nov 20 2006 seife@suse.de
- sync with current CVS, some of our patches went upstream
- print "Preparing suspend..." so the user has some feedback
* Thu Nov 16 2006 seife@suse.de
- comment the available variables in the configuration file
* Wed Nov  8 2006 seife@suse.de
- update to current CVS, some of our fixes incorporated upstream
- increase the logging output of the pm-utils-suse hooks
* Mon Nov  6 2006 hmacht@suse.de
- add 23dock hook to undock before suspend and redock after resume
* Mon Oct 30 2006 seife@suse.de
- update to current CVS, some of our fixes incorporated upstream
* Fri Oct 27 2006 hmacht@suse.de
- readd lost S2DISK_BIN and S2DISK_CONF variables
* Tue Oct 24 2006 hmacht@suse.de
- update to current CVS, some fixes incorporated upstream.
- add logging functionality
- add hook for ejecting pcmcia cards
* Mon Oct 23 2006 hmacht@suse.de
- add hook to log lsmod and free
* Wed Oct 11 2006 seife@suse.de
- small fixes, disable not yet ready logging code
* Tue Oct 10 2006 seife@suse.de
- update to current CVS, our fixes incorporated upstream.
- some additional hooks, converted from powersaved.
* Fri Oct  6 2006 seife@suse.de
- initial submission
